//----------------------------------------------------------------------
// parallel_plate.geo
// A parallel plate capacitor built from two gf_rectangle objects.
// ---------------------------------------------------------------------

SetFactory("OpenCASCADE");

// Create the counters.
n_physv = 1; // physical volumes
n_physs = 1; // physical surfaces
n_bdry = 0;  // number of boundary surfaces

// Include the components.
Include "rectangle.geo";
Include "wire_X.geo";
Include "wire_Y.geo";
Include "halfWire_X.geo";
Include "halfWire_Y.geo";

Detector_cathode = 1.5;
Detector_anode = 0.;
Detector_FG = 0.5;
MESH_R = 0.0025; 
MESH_void = 0.0470; 
MESH_pitch = MESH_void+2*MESH_R; MESH_pitchX2 = 2*MESH_pitch;
STEP_tot = 1; MESH_dim_X = STEP_tot*MESH_pitch; MESH_dim_X = STEP_tot*MESH_pitch;

Detector_h = Detector_cathode;
Detector_l = MESH_dim_X;
Detector_w = MESH_dim_X;
LC = MESH_R*3;
LC_BL = MESH_R/4.; //0.05 works fine
BoxHalfSize = 0.01;

Coherence Mesh; 
Mesh.CharacteristicLengthMin = LC_BL;
Mesh.CharacteristicLengthMax = LC;
Mesh.CharacteristicLengthFromCurvature = 1;
Mesh.CharacteristicLengthFromPoints = 1;
Mesh.MinimumCirclePoints = 30; //Default 7
Mesh.MinimumCurvePoints = 50; //Default 1


// Create the inner box, the top and bottom of which will be assigned voltages.
x0 = 0; y0 = 0; z0 = Detector_h/2.+Detector_anode; lc = LC; l = Detector_l; w = Detector_w; h = Detector_h;
vol = -1; s1 = -1; s2 = -1; s3 = -1; s4 = -1; s5 = -1; s6 = -1;
Call gf_rectangle;

// Save the surface IDs for the top and bottom of the inner box and volume.
s_top_plate = s5;
s_bottom_plate = s6;
vol_inner = vol;
Printf("Gas volume=%g", vol_inner);
// Create physical surfaces for the top and bottom plates.
physs_top_plate = n_physs; Physical Surface("cathode_surface") = {s_top_plate}; n_physs += 1;
physs_bottom_plate = n_physs; Physical Surface("anode_surface") = {s_bottom_plate}; n_physs += 1;

// Surface for periodic boundary conditions for the gas volume
Physical Surface("surf_gas_X_plus") = {s3};
Physical Surface("surf_gas_X_minus") = {s1};
Physical Surface("surf_gas_Y_plus") = {s2};
Physical Surface("surf_gas_Y_minus") = {s4};

// Create the physical volumes.
physv_gas = n_physv; Physical Volume("gas_volume") = {vol_inner}; n_physv += 1;


	lc = LC_BL; x0=0.; y0=0. ; z0=Detector_FG; dx = -Mesh_pitch/2; dy=-MESH_pitch/2; dz=0.;
	Mesh_R = MESH_R; Mesh_void = MESH_void; Mesh_pitch = MESH_pitch; Mesh_pitchX2 = MESH_pitchX2;
	Step = STEP_tot; Mesh_dim_X = MESH_dim_X; VolX = 0.; WireSide = -1; 
	Call halfWire_Xaxis; 
	

	lc = LC_BL; x0= 0.; y0=0.; z0=Detector_FG; dx=-MESH_pitch/2; dy=-MESH_pitch/2; dz=0.;
	Mesh_R = MESH_R; Mesh_void = MESH_void; Mesh_pitch = MESH_pitch; Mesh_pitchX2 = MESH_pitchX2;
	Step = STEP_tot; Mesh_dim_X = MESH_dim_X; VolY = 0.; WireSide = -1; 
	Call halfWire_Yaxis;
	//Save volume id
	volX_1 = VolX; volY_1 = VolY;
	

	lc = LC_BL; x0=0.; y0= 0.; z0=Detector_FG; dx=-Mesh_pitch/2; dy=MESH_pitch/2; dz=0.;
	Mesh_R = MESH_R; Mesh_void = MESH_void; Mesh_pitch = MESH_pitch; Mesh_pitchX2 = MESH_pitchX2;
	Step = STEP_tot; Mesh_dim_X = MESH_dim_X; VolX = 0.; WireSide = 1; 
	Call halfWire_Xaxis; 
	

	lc = LC_BL; x0= 0.; y0=0.; z0=Detector_FG; dx=MESH_pitch/2; dy=-MESH_pitch/2; dz=0.;
	Mesh_R = MESH_R; Mesh_void = MESH_void; Mesh_pitch = MESH_pitch; Mesh_pitchX2 = MESH_pitchX2;
	Step = STEP_tot; Mesh_dim_X = MESH_dim_X; VolY = 0.; WireSide = 1; 
	Call halfWire_Yaxis;
	//save volume id
	volX_2 = VolX; volY_2 = VolY;
	
	vol_union_3 = BooleanUnion {Volume{volY_1}; Delete;} {Volume{volX_1}; Delete;}; 
	vol_union_4 = BooleanUnion {Volume{volX_2}; Delete;} {Volume{vol_union_3}; Delete;};
	vol_union = BooleanUnion {Volume{volY_2}; Delete;} {Volume{vol_union_4}; Delete;};
	wireSurf[]=Boundary{Volume{vol_union};};

	Printf("Mesh_volume=%g", vol_union);
	Physical Volume("mesh_volume") = { vol_union };
	Physical Surface("mesh_surface") = {wireSurf[]};


n_physv += 1; ///Physical volume creation in 'mesh_design'
n_physs +=1;



Field[1] = Box;
Field[1].VIn = LC_BL;
Field[1].VOut = LC;
Field[1].XMin = -MESH_dim_X/2.; Field[1].XMax = MESH_dim_X/2.;
Field[1].YMin = -MESH_dim_X/2.; Field[1].YMax = MESH_dim_X/2.;
Field[1].ZMin = Detector_FG-BoxHalfSize; Field[1].ZMax = Detector_FG+BoxHalfSize;
Background Field = 1;


	
